/*

 *    CollectionInfoDialog.java
 *    Copyright (C) 2001 New Zealand Digital Library Project

 *

 *    This program is free software; you can redistribute it and/or modify

 *    it under the terms of the GNU General Public License as published by

 *    the Free Software Foundation; either version 2 of the License, or

 *    (at your option) any later version.

 *

 *    This program is distributed in the hope that it will be useful,

 *    but WITHOUT ANY WARRANTY; without even the implied warranty of

 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the

 *    GNU General Public License for more details.

 *

 *    You should have received a copy of the GNU General Public License

 *    along with this program; if not, write to the Free Software

 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

 */


package org.nzdl.gsdl.SimpleGraphicalClient;

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;
import java.text.*;

import org.nzdl.gsdl.service.*;

public class CollectionInfoDialog extends JDialog implements ActionListener {

private JButton okButton;
private JPanel  buttonPanel, holderPanel, contentPanel;
    private String publicString, betaString;

CollectionInfoDialog(Frame f, String collectionName, CSModel csModel) {
    super(f, "Collection Information" );

    contentPanel = new JPanel(new GridLayout(0,2, 5, 4));;
	  		
    buttonPanel = new JPanel();

    JLabel prefTitle = new JLabel(collectionName, SwingConstants.CENTER);
    prefTitle.setAlignmentX(JLabel.CENTER_ALIGNMENT);
    JPanel prefTitlePanel = new JPanel();
    prefTitlePanel.add(prefTitle);

    NzdlCollectionInfo collectionInfo =  csModel.getNzdlService().getCollectionInfo(collectionName);

    contentPanel.add(new JLabel("Collection:"));
    JLabel collectionLabel = new JLabel(collectionName);
    contentPanel.add(collectionLabel);
    contentPanel.add(new JLabel("Number of Documents:"));
    contentPanel.add(new JLabel("" + collectionInfo.getNumOfDocs()));
    contentPanel.add(new JLabel("Number of Words:"));
    contentPanel.add(new JLabel("" +  collectionInfo.getNumOfWords()));
    contentPanel.add(new JLabel("Size:"));
    contentPanel.add(new JLabel((collectionInfo.getNumOfBytes() / 1024) + "K"));
    contentPanel.add(new JLabel("Last built on:"));
    Date buildDate = new Date( collectionInfo.getBuildDate());
    contentPanel.add(new JLabel(DateFormat.getDateTimeInstance().format(buildDate)));
    Date now = new Date();
    Date now2 = new Date(now.getTime());
    System.err.println("Build date =\t " + collectionInfo.getBuildDate() + "\nNow is = \t" +  now.getTime());
    contentPanel.add(new JLabel("Today is:"));
    contentPanel.add( new JLabel(DateFormat.getDateTimeInstance().format(now2)));
    contentPanel.add(new JLabel("Is it Public?"));

    if (collectionInfo.isPublic())
	publicString = "yes";
    else
	publicString = "no";
    contentPanel.add(new JLabel(publicString));
    contentPanel.add(new JLabel("Is it beta?"));
    if (collectionInfo.isBeta())
	betaString = "yes";
    else
	betaString = "no";
    contentPanel.add(new JLabel(betaString));

    okButton = new JButton("Ok");
    okButton.setPreferredSize(new Dimension(80,20));
    okButton.addActionListener(this);
    buttonPanel.add( okButton );
    getRootPane().setDefaultButton(okButton);

    holderPanel = new JPanel();
    holderPanel.setBorder(BorderFactory.createEmptyBorder(10,10,2,10));
    holderPanel.setLayout( new BorderLayout());
    holderPanel.add( contentPanel, BorderLayout.NORTH);
    holderPanel.add( buttonPanel, BorderLayout.SOUTH);
    getContentPane().add(holderPanel);
    //setSize(new Dimension(300,300));

    pack();
    setVisible(true);
} //end CollectionInfoDialog constructor



public void actionPerformed(ActionEvent e) {
    Object source = e.getSource();
    if (source == okButton)
	{
	    //System.err.println("ok button pressed!");

	    dispose(); //close window
	}
    else
	{
		System.err.println("event not processed in CollectionInfoDialog");
	}
} //end actionPerformed

} // end CollectionInfoDialog class
